
from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from ntnx_dataprotection_py_client.api.protected_resources_api import ProtectedResourcesApi
from ntnx_dataprotection_py_client.api.recovery_points_api import RecoveryPointsApi
