# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.DiskRecoveryPoint import DiskRecoveryPoint  # noqa: F401,E501

class VolumeGroupRecoveryPoint(ExternalizableAbstractModel):

    """A model that represents volume group recovery point properties.

    :param consistency_group_ext_id: (:attr:`consistency_group_ext_id`) External identifier of the Consistency group which the entity was part of at the time of recovery point creation.
    :type consistency_group_ext_id: 
    
    
    :param location_agnostic_id: (:attr:`location_agnostic_id`) Location agnostic identifier of the recovery point. This identifier is used to identify the same instances of a recovery point across different sites.
    :type location_agnostic_id: 
    
    
    :param volume_group_ext_id: (:attr:`volume_group_ext_id`) Volume Group external identifier which is captured as part of this recovery point.
    :type volume_group_ext_id: required
    
    
    :param volume_group_categories: (:attr:`volume_group_categories`) Category key-value pairs associated with the volume group at the time of recovery point creation. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' will be represented as 'dept/hr'.
    :type volume_group_categories: 
    
    
    :param disk_recovery_points: (:attr:`disk_recovery_points`) 
    :type disk_recovery_points: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'consistency_group_ext_id': 'str',
        'location_agnostic_id': 'str',
        'volume_group_ext_id': 'str',
        'volume_group_categories': 'list[str]',
        'disk_recovery_points': 'list[dataprotection.v4.common.DiskRecoveryPoint]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'consistency_group_ext_id': 'consistencyGroupExtId',
        'location_agnostic_id': 'locationAgnosticId',
        'volume_group_ext_id': 'volumeGroupExtId',
        'volume_group_categories': 'volumeGroupCategories',
        'disk_recovery_points': 'diskRecoveryPoints',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, consistency_group_ext_id=None, location_agnostic_id=None, volume_group_ext_id=None, volume_group_categories=None, disk_recovery_points=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__consistency_group_ext_id = None
        self.__location_agnostic_id = None
        self.__volume_group_ext_id = None
        self.__volume_group_categories = None
        self.__disk_recovery_points = None
        self.discriminator = None
        if consistency_group_ext_id is not None:
            self.__consistency_group_ext_id = consistency_group_ext_id
        if location_agnostic_id is not None:
            self.__location_agnostic_id = location_agnostic_id
        self.__volume_group_ext_id = volume_group_ext_id
        if volume_group_categories is not None:
            self.__volume_group_categories = volume_group_categories
        if disk_recovery_points is not None:
            self.__disk_recovery_points = disk_recovery_points

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.VolumeGroupRecoveryPoint'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def consistency_group_ext_id(self):
        """
        External identifier of the Consistency group which the entity was part of at the time of recovery point creation.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__consistency_group_ext_id

    @consistency_group_ext_id.setter
    def consistency_group_ext_id(self, consistency_group_ext_id):
        if consistency_group_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', consistency_group_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `consistency_group_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__consistency_group_ext_id = consistency_group_ext_id

    @property
    def location_agnostic_id(self):
        """
        Location agnostic identifier of the recovery point. This identifier is used to identify the same instances of a recovery point across different sites.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__location_agnostic_id

    @location_agnostic_id.setter
    def location_agnostic_id(self, location_agnostic_id):
        if location_agnostic_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', location_agnostic_id):  # noqa: E501
            raise ValueError(r"Invalid value for `location_agnostic_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__location_agnostic_id = location_agnostic_id

    @property
    def volume_group_ext_id(self):
        """
        Volume Group external identifier which is captured as part of this recovery point.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__volume_group_ext_id

    @volume_group_ext_id.setter
    def volume_group_ext_id(self, volume_group_ext_id):
        if volume_group_ext_id is None:
            raise ValueError("Invalid value for `volume_group_ext_id`, must not be `None`")  # noqa: E501
        if volume_group_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', volume_group_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `volume_group_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__volume_group_ext_id = volume_group_ext_id

    @property
    def volume_group_categories(self):
        """
        Category key-value pairs associated with the volume group at the time of recovery point creation. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' will be represented as 'dept/hr'.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__volume_group_categories

    @volume_group_categories.setter
    def volume_group_categories(self, volume_group_categories):

        self.__volume_group_categories = volume_group_categories

    @property
    def disk_recovery_points(self):
        """
        

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.common.DiskRecoveryPoint` ]
        """  # noqa: E501
        return self.__disk_recovery_points

    @disk_recovery_points.setter
    def disk_recovery_points(self, disk_recovery_points):

        self.__disk_recovery_points = disk_recovery_points

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VolumeGroupRecoveryPoint, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeGroupRecoveryPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

