# coding: utf-8

# flake8: noqa

"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

# import models into model package
from ntnx_dataprotection_py_client.models.OneOfcommon.v1.config.KVPairvalue import KVPairvalue
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.common.BaseVmRecoveryPointapplication_consistent_properties import BaseVmRecoveryPointapplication_consistent_properties
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ClusterInfoApiResponsedata import ClusterInfoApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.CreateConsistencyGroupApiResponsedata import CreateConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.CreateRecoveryPointApiResponsedata import CreateRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DeleteConsistencyGroupApiResponsedata import DeleteConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DeleteRecoveryPointApiResponsedata import DeleteRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.GetProtectedResourceApiResponsedata import GetProtectedResourceApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.GetRecoveryPointApiResponsedata import GetRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.GetVmRecoveryPointApiResponsedata import GetVmRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ListRecoveryPointsApiResponsedata import ListRecoveryPointsApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.MigrateConsistencyGroupApiResponsedata import MigrateConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourcePromoteApiResponsedata import ProtectedResourcePromoteApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourceRestoreApiResponsedata import ProtectedResourceRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointReplicateApiResponsedata import RecoveryPointReplicateApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointRepositoryProjectionobject_storage_reference import RecoveryPointRepositoryProjectionobject_storage_reference
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointRepositoryobject_storage_reference import RecoveryPointRepositoryobject_storage_reference
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointRestoreApiResponsedata import RecoveryPointRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.SynchronousReplicaPromoteApiResponsedata import SynchronousReplicaPromoteApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.UpdateConsistencyGroupApiResponsedata import UpdateConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponsedata import UpdateRecoveryPointExpirationTimeApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VmRecoveryPointapplication_consistent_properties import VmRecoveryPointapplication_consistent_properties
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ChangedVmRegionsApiResponsedata import ChangedVmRegionsApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ChangedVolumeGroupRegionsApiResponsedata import ChangedVolumeGroupRegionsApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ClusterDiscoverSpecspec import ClusterDiscoverSpecspec
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ComputeChangedRegionsClusterDiscoverSpecdisk_recovery_point import ComputeChangedRegionsClusterDiscoverSpecdisk_recovery_point
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ComputeChangedRegionsClusterDiscoverSpecreference_disk_recovery_point import ComputeChangedRegionsClusterDiscoverSpecreference_disk_recovery_point
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.GetVssMetadataApiResponsedata import GetVssMetadataApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.error.ErrorResponseerror import ErrorResponseerror
from ntnx_dataprotection_py_client.models.common.v1.config.Flag import Flag
from ntnx_dataprotection_py_client.models.common.v1.config.IPAddress import IPAddress
from ntnx_dataprotection_py_client.models.common.v1.config.IPv4Address import IPv4Address
from ntnx_dataprotection_py_client.models.common.v1.config.IPv6Address import IPv6Address
from ntnx_dataprotection_py_client.models.common.v1.config.KVPair import KVPair
from ntnx_dataprotection_py_client.models.common.v1.config.MapOfStringWrapper import MapOfStringWrapper
from ntnx_dataprotection_py_client.models.common.v1.config.Message import Message
from ntnx_dataprotection_py_client.models.common.v1.config.MessageSeverity import MessageSeverity
from ntnx_dataprotection_py_client.models.common.v1.config.TenantAwareModel import TenantAwareModel
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink
from ntnx_dataprotection_py_client.models.common.v1.response.ApiResponseMetadata import ApiResponseMetadata
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BackupType import BackupType
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseRecoveryPoint import BaseRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseVmRecoveryPoint import BaseVmRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.ClusterInfo import ClusterInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.DiskRecoveryPoint import DiskRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointStatus import RecoveryPointStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointType import RecoveryPointType
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.VssProperties import VssProperties
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.AhvVmOverrideSpec import AhvVmOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.AmazonS3Bucket import AmazonS3Bucket
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.AzureBlobStorageContainer import AzureBlobStorageContainer
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ClusterInfoApiResponse import ClusterInfoApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroup import ConsistencyGroup
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMember import ConsistencyGroupMember
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMemberType import ConsistencyGroupMemberType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMigrationSpec import ConsistencyGroupMigrationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupProjection import ConsistencyGroupProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.CreateConsistencyGroupApiResponse import CreateConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.CreateRecoveryPointApiResponse import CreateRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference import DataProtectionSiteReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteConsistencyGroupApiResponse import DeleteConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteRecoveryPointApiResponse import DeleteRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.EsxiVmOverrideSpec import EsxiVmOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ExpirationTimeSpec import ExpirationTimeSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.GetProtectedResourceApiResponse import GetProtectedResourceApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.GetRecoveryPointApiResponse import GetRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.GetVmRecoveryPointApiResponse import GetVmRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostReference import HostReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostType import HostType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.IpAddress import IpAddress
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ListRecoveryPointsApiResponse import ListRecoveryPointsApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.LocationReference import LocationReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.MigrateConsistencyGroupApiResponse import MigrateConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.NutanixObjectsBucket import NutanixObjectsBucket
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ObjectStorageType import ObjectStorageType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedEntityType import ProtectedEntityType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResource import ProtectedResource
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourcePromoteApiResponse import ProtectedResourcePromoteApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceReplicationStatus import ProtectedResourceReplicationStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreApiResponse import ProtectedResourceRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreSpec import ProtectedResourceRestoreSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryInfo import RecoveryInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPoint import RecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointProjection import RecoveryPointProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicateApiResponse import RecoveryPointReplicateApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicationSpec import RecoveryPointReplicationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRepository import RecoveryPointRepository
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRepositoryProjection import RecoveryPointRepositoryProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestorationSpec import RecoveryPointRestorationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestoreApiResponse import RecoveryPointRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ReplicationState import ReplicationState
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RestorableTimeRange import RestorableTimeRange
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteProtectionInfo import SiteProtectionInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteReference import SiteReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SynchronousReplicaPromoteApiResponse import SynchronousReplicaPromoteApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SynchronousReplicationRole import SynchronousReplicationRole
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.UpdateConsistencyGroupApiResponse import UpdateConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponse import UpdateRecoveryPointExpirationTimeApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPoint import VmRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPointRestoreOverride import VmRecoveryPointRestoreOverride
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupOverrideSpec import VolumeGroupOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPoint import VolumeGroupRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointRestoreOverride import VolumeGroupRecoveryPointRestoreOverride
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSyncContext import VolumeGroupSyncContext
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Witness import Witness
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.WitnessAvailabilityStatus import WitnessAvailabilityStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.BaseRecoveryPointSpec import BaseRecoveryPointSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ChangedRegion import ChangedRegion
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ChangedVmRegionsApiResponse import ChangedVmRegionsApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ChangedVolumeGroupRegionsApiResponse import ChangedVolumeGroupRegionsApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ClusterDiscoverOperation import ClusterDiscoverOperation
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ClusterDiscoverSpec import ClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ComputeChangedRegionsClusterDiscoverSpec import ComputeChangedRegionsClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.DiskRecoveryPointReference import DiskRecoveryPointReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.GetVssMetadataApiResponse import GetVssMetadataApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.GetVssMetadataClusterDiscoverSpec import GetVssMetadataClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.RegionType import RegionType
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VmDiskRecoveryPointClusterDiscoverSpec import VmDiskRecoveryPointClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VmDiskRecoveryPointReference import VmDiskRecoveryPointReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VmRecoveryPointChangedRegionsComputeSpec import VmRecoveryPointChangedRegionsComputeSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VolumeGroupDiskRecoveryPointClusterDiscoverSpec import VolumeGroupDiskRecoveryPointClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VolumeGroupDiskRecoveryPointReference import VolumeGroupDiskRecoveryPointReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VolumeGroupRecoveryPointChangedRegionsComputeSpec import VolumeGroupRecoveryPointChangedRegionsComputeSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.AppMessage import AppMessage
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.ErrorResponse import ErrorResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.SchemaValidationError import SchemaValidationError
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.SchemaValidationErrorMessage import SchemaValidationErrorMessage
from ntnx_dataprotection_py_client.models.prism.v4.config.TaskReference import TaskReference
from ntnx_dataprotection_py_client.api_response import ApiResponse
