# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import urllib3
from urllib3.connectionpool import HTTPConnectionPool
from urllib3.connectionpool import HTTPSConnectionPool

class CustomPoolManager(urllib3.PoolManager):
    def __init__(self, *args, **kwargs):
        super().__init__(
            num_pools=args[0],
            maxsize=args[1],
            cert_reqs=args[2],
            ca_certs=args[3],
            cert_file=args[4],
            key_file=args[5],
            retries = args[6],
            **kwargs
        )

        self.pool_classes_by_scheme = {
            'http': HTTPConnectionPool,
            'https': HTTPSConnectionPool,
        }

    # Override urlopen to make default value of the redirect parameter as False
    def urlopen(self, method, url, redirect=False, **kw):
        return super().urlopen(method, url, redirect, **kw)

